==> aloe-1.3.tar.gz: aloe-1.3/modules/wimax_symboldemap/src/symboldemap_code.c <==
#include <math.h>
#include <stdio.h>
#include <stdlib.h>
 
#include "symboldemap_code.h"
#include "CSymboldemap.h"



float abso (float x)
{
	float y;
	
	return y=sqrt(x*x);	
}


void symboldemap(int MOD,\
			int channel_len,\
			symbol *in_array,\
			int *new_ch_len,\
			float *out_array)
{
//x: it refers to the number of bits per symbol
	
	int t;
	float RE,IM;
//	float array[channel_len*MOD];
//	int quantizer_table[BSIZE];
	
	int new_channel_len;
	
	new_channel_len=channel_len*MOD;	//BPSK=1, QPSK=2, 16QAM=4, 64QAM=6
	
	if (MOD==_BPSK){
		for (t=0;t<channel_len;t++){
			out_array[t] = in_array[t].re;
		}
	}
	if (MOD==_QPSK){
		for (t=0;t<channel_len;t++){
			RE=in_array[t].re*sqrt(2.0);
			IM=in_array[t].im*sqrt(2.0);
			out_array[t*2] = RE;
			out_array[t*2+1] = IM;
		}
	
	}
	if (MOD==_16QAM){
		for (t=0;t<channel_len;t++){
			RE=in_array[t].re*sqrt(10.0);
      			IM=in_array[t].im*sqrt(10.0);

			if (abso(RE)<=1.0) out_array[4*t]=1.0;
			else if ((1.0<abso(RE))&&(abso(RE)<=3.0)) out_array[4*t]=-abso(RE)+2.0;
			else if (3.0<abso(RE)) out_array[4*t]=-1.0;
			
			out_array[4*t+1]=RE;
			
			if (abso(IM)<=1.0) out_array[4*t+2]=1.0;
			else if ((1.0<abso(IM))&&(abso(IM)<=3.0)) out_array[4*t+2]=-abso(IM)+2.0;
			else if (3.0<abso(IM)) out_array[4*t+2]=-1.0;
			
			out_array[4*t+3]=IM;
		
		}
	//	for (t=0;t<channel_len*MOD;t++) printf(" out_array=%f ",out_array[t]);
	}
	if(MOD==_64QAM){
		for (t=0;t<channel_len;t++){
			RE=in_array[t].re*sqrt(42.0);
      			IM=in_array[t].im*sqrt(42.0);
					
			if (abso(RE)<=1.0) out_array[6*t]=-1.0;
			else if ((1.0<abso(RE))&&(abso(RE)<=3.0)) out_array[6*t]=abso(RE)-2.0;
			else if ((3.0<abso(RE))&&(abso(RE)<=5.0)) out_array[6*t]=+1.0;
			else if ((5.0<abso(RE))&&(abso(RE)<=7.0)) out_array[6*t]=-abso(RE)+6.0;
			else if (7.0<abso(RE)) out_array[6*t]=-1.0;
			
			if (abso(RE)<=3.0) out_array[6*t+1]=1.0;
			else if ((3.0<abso(RE))&&(abso(RE)<=5.0)) out_array[6*t+1]=-abso(RE)+4.0;
			else if (5.0<abso(RE)) out_array[6*t+1]=-1.0;
			
			out_array[6*t+2]=RE;
			
			if (abso(IM)<=1.0) out_array[6*t+3]=-1.0;
			else if ((1.0<abso(IM))&&(abso(IM)<=3.0)) out_array[6*t+3]=abso(IM)-2.0;
			else if ((3.0<abso(IM))&&(abso(IM)<=5.0)) out_array[6*t+3]=+1.0;
			else if ((5.0<abso(IM))&&(abso(IM)<=7.0)) out_array[6*t+3]=-abso(IM)+6.0;
			else if (7.0<abso(IM)) out_array[6*t+3]=-1.0;
			
			if (abso(IM)<=3.0) out_array[6*t+4]=1.0;
			else if ((3.0<abso(IM))&&(abso(IM)<=5.0)) out_array[6*t+4]=-abso(IM)+4.0;
			else if (5.0<abso(IM)) out_array[6*t+4]=-1.0;
			
			out_array[6*t+5]=IM;
		}


	}
	
}

==> aloe-1.4.5.tar.gz: aloe-1.4.5/modules/wimax_symboldemap/src/symboldemap_code.c <==
#include <math.h>
#include <stdio.h>
#include <stdlib.h>
 
#include "symboldemap_code.h"
#include "CSymboldemap.h"



float abso (float x)
{
	float y;
	
	return y=sqrt(x*x);	
}


int symboldemap(int MOD,\
			int channel_len,\
			symbol *in_array,\
			float *out_array)
{
//x: it refers to the number of bits per symbol
	
	int t;
	float RE,IM;
//	float array[channel_len*MOD];
//	int quantizer_table[BSIZE];
	
	int new_channel_len;
	
	new_channel_len=channel_len*MOD;	//BPSK=1, QPSK=2, 16QAM=4, 64QAM=6
	
	if (MOD==_BPSK){
		for (t=0;t<channel_len;t++){
			out_array[t] = -in_array[t].re;
		}
	}
	if (MOD==_QPSK){
		for (t=0;t<channel_len;t++){
			RE=in_array[t].re*sqrt(2.0);
			IM=in_array[t].im*sqrt(2.0);
			out_array[t*2] = RE;
			out_array[t*2+1] = IM;

                        out_array[2*t]=-out_array[2*t];
                        out_array[2*t+1]=-out_array[2*t+1];
		}
	
	}
	if (MOD==_16QAM){
		for (t=0;t<channel_len;t++){
			RE=in_array[t].re*sqrt(10.0);
      			IM=in_array[t].im*sqrt(10.0);

			if (abso(RE)<=1.0) out_array[4*t]=1.0;
			else if ((1.0<abso(RE))&&(abso(RE)<=3.0)) out_array[4*t]=-abso(RE)+2.0;
			else if (3.0<abso(RE)) out_array[4*t]=-1.0;
			
			out_array[4*t+1]=RE;
			
			if (abso(IM)<=1.0) out_array[4*t+2]=1.0;
			else if ((1.0<abso(IM))&&(abso(IM)<=3.0)) out_array[4*t+2]=-abso(IM)+2.0;
			else if (3.0<abso(IM)) out_array[4*t+2]=-1.0;
			
			out_array[4*t+3]=IM;

                        out_array[4*t]=-out_array[4*t];
                        out_array[4*t+1]=-out_array[4*t+1];
                        out_array[4*t+2]=-out_array[4*t+2];
                        out_array[4*t+3]=-out_array[4*t+3];


		}
	//	for (t=0;t<channel_len*MOD;t++) printf(" out_array=%f ",out_array[t]);
	}
	if(MOD==_64QAM){
		for (t=0;t<channel_len;t++){
			RE=in_array[t].re*sqrt(42.0);
      			IM=in_array[t].im*sqrt(42.0);
					
			if (abso(RE)<=1.0) out_array[6*t]=-1.0;
			else if ((1.0<abso(RE))&&(abso(RE)<=3.0)) out_array[6*t]=abso(RE)-2.0;
			else if ((3.0<abso(RE))&&(abso(RE)<=5.0)) out_array[6*t]=+1.0;
			else if ((5.0<abso(RE))&&(abso(RE)<=7.0)) out_array[6*t]=-abso(RE)+6.0;
			else if (7.0<abso(RE)) out_array[6*t]=-1.0;
			
			if (abso(RE)<=3.0) out_array[6*t+1]=1.0;
			else if ((3.0<abso(RE))&&(abso(RE)<=5.0)) out_array[6*t+1]=-abso(RE)+4.0;
			else if (5.0<abso(RE)) out_array[6*t+1]=-1.0;
			
			out_array[6*t+2]=RE;
			
			if (abso(IM)<=1.0) out_array[6*t+3]=-1.0;
			else if ((1.0<abso(IM))&&(abso(IM)<=3.0)) out_array[6*t+3]=abso(IM)-2.0;
			else if ((3.0<abso(IM))&&(abso(IM)<=5.0)) out_array[6*t+3]=+1.0;
			else if ((5.0<abso(IM))&&(abso(IM)<=7.0)) out_array[6*t+3]=-abso(IM)+6.0;
			else if (7.0<abso(IM)) out_array[6*t+3]=-1.0;
			
			if (abso(IM)<=3.0) out_array[6*t+4]=1.0;
			else if ((3.0<abso(IM))&&(abso(IM)<=5.0)) out_array[6*t+4]=-abso(IM)+4.0;
			else if (5.0<abso(IM)) out_array[6*t+4]=-1.0;
			
			out_array[6*t+5]=IM;


                        out_array[6*t]=-out_array[6*t];
                        out_array[6*t+1]=-out_array[6*t+1];
                        out_array[6*t+2]=-out_array[6*t+2];
                        out_array[6*t+3]=-out_array[6*t+3];
                        out_array[6*t+4]=-out_array[6*t+4];
                        out_array[6*t+5]=-out_array[6*t+5];
                        
                        //Onother version
                       /* out_array[6*t+2]=-RE;
                        out_array[6*t+1]=abso(RE)-2.0;
                        out_array[6*t]=abso(abso(RE)-4.0)-2;
                       */




		}


	}
        return(new_channel_len);
	
}
